nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Csc1Coef0

Struct Csc1Coef0 

#[repr(transparent)]
pub struct Csc1Coef0(pub u32);
Color Space Conversion Coefficient Register 0

Tuple Fields

0: u32

Implementations

Source

impl Csc1Coef0

pub const fn y_offset(&self) -> u16

Two’s compliment amplitude offset implicit in the Y data

pub const fn set_y_offset(&mut self, val: u16)

Two’s compliment amplitude offset implicit in the Y data

pub const fn uv_offset(&self) -> u16

Two’s compliment phase offset implicit for CbCr data

pub const fn set_uv_offset(&mut self, val: u16)

Two’s compliment phase offset implicit for CbCr data

pub const fn c0(&self) -> u16

Two’s compliment Y multiplier coefficient. YUV=0x100 (1.000) YCbCr=0x12A (1.164)

pub const fn set_c0(&mut self, val: u16)

Two’s compliment Y multiplier coefficient. YUV=0x100 (1.000) YCbCr=0x12A (1.164)

pub const fn bypass(&self) -> bool

Bypass the CSC unit in the scaling engine

pub const fn set_bypass(&mut self, val: bool)

Bypass the CSC unit in the scaling engine

pub const fn ycbcr_mode(&self) -> YcbcrMode

Set to 1 when performing YCbCr conversion to RGB

pub const fn set_ycbcr_mode(&mut self, val: YcbcrMode)

Set to 1 when performing YCbCr conversion to RGB