nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

PsPitch

Struct PsPitch 

#[repr(transparent)]
pub struct PsPitch(pub u32);
Processed Surface Pitch

Tuple Fields

0: u32

Implementations

Source

impl PsPitch

pub const fn pitch(&self) -> u16

Indicates the number of bytes in memory between two vertically adjacent pixels.

pub const fn set_pitch(&mut self, val: u16)

Indicates the number of bytes in memory between two vertically adjacent pixels.